##
##  vcdiff.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_base 0.8.4
%define       V_snap 20230624

#   package information
Name:         vcdiff
Summary:      Binary Difference Tool
URL:          https://github.com/google/open-vcdiff
Vendor:       Google Inc. & Lincoln Smith
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Patching
License:      Apache
Version:      %{V_base}.%{V_snap}
Release:      20230624

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/vcdiff/vcdiff-%{V_snap}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes
PreReq:       OpenPKG, openpkg >= 20160101

%description
    open-vcdiff is an encoder and decoder that can write and read the
    VCDIFF format described in RFC 3284 "The VCDIFF Generic Differencing
    and Compression Data Format". The encoder uses the Bentley/McIlroy
    technique for finding matches between the dictionary and target
    data. The following non-standard extensions to the VCDIFF format
    can be enabled if desired: interleaved format, Adler32 checksum and
    version header byte (Header4).

%track
    prog vcdiff:base = {
        version   = %{V_base}
        url       = https://github.com/google/open-vcdiff/tags
        regex     = tag/openvcdiff-(__VER__)
    }
    prog vcdiff:snap = {
        version   = %{V_snap}
        url       = http://download.openpkg.org/components/versioned/vcdiff/
        regex     = vcdiff-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n vcdiff

%build
    HOME=`pwd`
    mkdir build
    cd build
    cmake \
        -DCMAKE_BUILD_TYPE="Release" \
        -DCMAKE_INSTALL_PREFIX="%{l_prefix}" \
        -DCMAKE_C_COMPILER="%{l_cc}" \
        -DCMAKE_C_FLAGS="%{l_cflags} %{l_cppflags}" \
        -DCMAKE_EXE_LINKER_FLAGS="%{l_ldflags}" \
        -DCMAKE_CXX_COMPILER="%{l_cxx}" \
        ..
    %{l_make} %{l_mflags -O}

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1
    %{l_shtool} install -c -s -m 755 \
        build/vcdiff $RPM_BUILD_ROOT%{l_prefix}/bin/
    %{l_shtool} install -c -m 644 \
        man/vcdiff.1 $RPM_BUILD_ROOT%{l_prefix}/man/man1/
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

